@@ -253,7 +253,7 @@ impl WebSocketContext {
             incomplete: None,
             send_queue: VecDeque::new(),
             pong: None,
-            config: config.unwrap_or_else(WebSocketConfig::default),
+            config: config.unwrap_or_default(),
         }
     }
 
@@ -356,6 +356,7 @@ impl WebSocketContext {
                 return self.write_pending(stream);
             }
             Message::Close(code) => return self.close(stream, code),
+            Message::Frame(f) => f,
         };
 
         self.send_queue.push_back(frame);
